        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==1 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==1 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==8 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==8 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==18 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==18 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==24 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==24 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==44 && cc==4){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==44 && cc==5){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==45 && cc==4){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==45 && cc==5){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
}
