        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==2 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==2 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==9 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==9 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==10 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==10 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==11 && cc==4){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==11 && cc==5){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==12 && cc==4){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==12 && cc==5){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==13 && cc==4){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==13 && cc==5){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==14 && cc==4){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==14 && cc==5){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==15 && cc==4){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==15 && cc==5){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 13 <br>3,6,8,10,11,13,14,17,20,22,24,29,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 13 <strong>control</strong><br>0,5,19,25,26,35,36,39,40,41,42,44,48';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>1,4,12,16,18,28,31,32,33,34';}
       if(rr==16 && cc==4){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 9 <br>2,7,9,27,37,43,45,46,47';}
       if(rr==16 && cc==5){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260606 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 6 <br>15,21,23,30,38,49';}
}
